Class: Azure::ContainerRegistry::Mgmt::V2019_04_01::Models::FileTaskRunRequest

Inherits:
RunRequest
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb

Overview

The request parameters for a scheduling run against a task file.

Instance Attribute Summary collapse

Attributes inherited from RunRequest

#is_archive_enabled

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeFileTaskRunRequest



16
17
18
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 16

def initialize
  @type = "FileTaskRunRequest"
end

Instance Attribute Details

#agent_configurationAgentProperties



42
43
44
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 42

def agent_configuration
  @agent_configuration
end

#credentialsCredentials

credentials that will be used when this run is invoked.



52
53
54
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 52

def credentials
  @credentials
end

#platformPlatformProperties

run has to happen.



39
40
41
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 39

def platform
  @platform
end

#source_locationString

It can be an URL to a tar or git repository. If it is relative URL, the relative path should be obtained from calling listBuildSourceUploadUrl API.



48
49
50
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 48

def source_location
  @source_location
end

#task_file_pathString

source.



24
25
26
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 24

def task_file_path
  @task_file_path
end

#timeoutInteger



35
36
37
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 35

def timeout
  @timeout
end

#typeObject

Returns the value of attribute type.



20
21
22
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 20

def type
  @type
end

#valuesArray<SetValue>

be passed when running a task.



32
33
34
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 32

def values
  @values
end

#values_file_pathString

source.



28
29
30
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 28

def values_file_path
  @values_file_path
end

Class Method Details

.mapperObject

Mapper for FileTaskRunRequest class as Ruby Hash. This will be used for serialization/deserialization.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/2019-04-01/generated/azure_mgmt_container_registry/models/file_task_run_request.rb', line 59

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'FileTaskRunRequest',
    type: {
      name: 'Composite',
      class_name: 'FileTaskRunRequest',
      model_properties: {
        is_archive_enabled: {
          client_side_validation: true,
          required: false,
          serialized_name: 'isArchiveEnabled',
          default_value: false,
          type: {
            name: 'Boolean'
          }
        },
        type: {
          client_side_validation: true,
          required: true,
          serialized_name: 'type',
          type: {
            name: 'String'
          }
        },
        task_file_path: {
          client_side_validation: true,
          required: true,
          serialized_name: 'taskFilePath',
          type: {
            name: 'String'
          }
        },
        values_file_path: {
          client_side_validation: true,
          required: false,
          serialized_name: 'valuesFilePath',
          type: {
            name: 'String'
          }
        },
        values: {
          client_side_validation: true,
          required: false,
          serialized_name: 'values',
          type: {
            name: 'Sequence',
            element: {
                client_side_validation: true,
                required: false,
                serialized_name: 'SetValueElementType',
                type: {
                  name: 'Composite',
                  class_name: 'SetValue'
                }
            }
          }
        },
        timeout: {
          client_side_validation: true,
          required: false,
          serialized_name: 'timeout',
          default_value: 3600,
          constraints: {
            InclusiveMaximum: 28800,
            InclusiveMinimum: 300
          },
          type: {
            name: 'Number'
          }
        },
        platform: {
          client_side_validation: true,
          required: true,
          serialized_name: 'platform',
          type: {
            name: 'Composite',
            class_name: 'PlatformProperties'
          }
        },
        agent_configuration: {
          client_side_validation: true,
          required: false,
          serialized_name: 'agentConfiguration',
          type: {
            name: 'Composite',
            class_name: 'AgentProperties'
          }
        },
        source_location: {
          client_side_validation: true,
          required: false,
          serialized_name: 'sourceLocation',
          type: {
            name: 'String'
          }
        },
        credentials: {
          client_side_validation: true,
          required: false,
          serialized_name: 'credentials',
          type: {
            name: 'Composite',
            class_name: 'Credentials'
          }
        }
      }
    }
  }
end